@@ -1,27 +1,30 @@
 context("Testing summary plot function")
 
 library(occCite)
+library(ggplot2)
 data("myOccCiteObject")
 
+print(paste0("Checking ggplot version...", packageVersion("ggplot2")))
+
 test_that("default sumFig settings work", {
   test <- plot(myOccCiteObject)
   expect_true("yearHistogram" %in% names(test))
-  expect_equal(class(test[[1]]), "ggplot_built")
+  expect_true(is_ggplot(test[[1]]))
   expect_true("source" %in% names(test))
-  expect_equal(class(test[[2]]), "ggplot_built")
+  expect_true(is_ggplot(test[[2]]))
   expect_true("aggregator" %in% names(test))
-  expect_equal(class(test[[3]]), "ggplot_built")
+  expect_true(is_ggplot(test[[3]]))
 })
 
 test_that("sumFig works when plotting by species", {
   test <- plot(myOccCiteObject, bySpecies = T)
   expect_true(names(test) == "Protea cynaroides")
   expect_true("yearHistogram" %in% names(test[[1]]))
-  expect_equal(class(test[[1]][[1]]), "ggplot_built")
+  expect_true(is_ggplot(test[[1]][[1]]))
   expect_true("source" %in% names(test[[1]]))
-  expect_equal(class(test[[1]][[2]]), "ggplot_built")
+  expect_true(is_ggplot(test[[1]][[2]]))
   expect_true("aggregator" %in% names(test[[1]]))
-  expect_equal(class(test[[1]][[3]]), "ggplot_built")
+  expect_true(is_ggplot(test[[1]][[3]]))
 })
 
 test_that("sumFig works when plotting only year histogram by species", {
@@ -29,7 +32,7 @@ test_that("sumFig works when plotting only year histogram by species", {
   test <- plot(myOccCiteObject, bySpecies = T, plotTypes = "yearHistogram")
   expect_true(names(test) == "Protea cynaroides")
   expect_true("yearHistogram" %in% names(test[[1]]))
-  expect_equal(class(test[[1]][[1]]), "ggplot_built")
+  expect_true(is_ggplot(test[[1]][[1]]))
 })
 
 test_that("sumFig works when plotting only source by species", {
@@ -37,7 +40,7 @@ test_that("sumFig works when plotting only source by species", {
   test <- plot(myOccCiteObject, bySpecies = T, plotTypes = "source")
   expect_true(names(test) == "Protea cynaroides")
   expect_true("source" %in% names(test[[1]]))
-  expect_equal(class(test[[1]][[1]]), "ggplot_built")
+  expect_true(is_ggplot(test[[1]][[1]]))
 })
 
 test_that("sumFig works when plotting only aggregator by species", {
@@ -45,5 +48,5 @@ test_that("sumFig works when plotting only aggregator by species", {
   test <- plot(x = myOccCiteObject, bySpecies = T, plotTypes = "aggregator")
   expect_true(names(test) == "Protea cynaroides")
   expect_true("aggregator" %in% names(test[[1]]))
-  expect_equal(class(test[[1]][[1]]), "ggplot_built")
+  expect_true(is_ggplot(test[[1]][[1]]))
 })
